# -*- coding: utf-8 -*-
# Generated by Django 1.9.10 on 2016-09-30 05:45
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('wagtailmenus', '0015_auto_20160423_1348'),
    ]

    operations = [
        migrations.AddField(
            model_name='flatmenuitem',
            name='handle',
            field=models.CharField(verbose_name="handle", blank=True, help_text='Use this field to optionally specify an additional value for each menu item, which you can then reference in custom menu templates.', max_length=100),
        ),
        migrations.AddField(
            model_name='mainmenuitem',
            name='handle',
            field=models.CharField(verbose_name="handle", blank=True, help_text='Use this field to optionally specify an additional value for each menu item, which you can then reference in custom menu templates.', max_length=100),
        ),
    ]
