{% load menu_tags %}
{% if menu_items %}
    <ul>
        {% for item in menu_items %}
        <li class="{{ item.active_class }}{% if item.link_page and item.link_page.extra_menuitem_css_class %} {{ item.link_page.extra_menuitem_css_class }}{% endif %}">
            <a href="{{ item.href }}">{{ item.text }}</a>
            {% if item.has_children_in_menu %}{% sub_menu item %}{% endif %}
        </li>
        {% endfor %}
    </ul>
{% endif %}

